##  Prerequisites
  * Administrator access in SAP LeanIX.
  * Ensure you are familiar with managing service accounts in Google Cloud Platform (GCP) and that you have sufficient permissions to grant access to Google Agent Engine.
